TransactionParams class

Constructors

TransactionParams({required int merchantId, required String crc, required String sessionId, required int amount, required String currency, required String description, required String email, required String country, String? client, String? address, String? zip, String? city, String? phone, String? language, int? method, String? urlStatus, int? timeLimit, int? channel, int? shipping, String? transferLabel, String? methodRefId, PassageCart? passageCart})

Properties

address → String?
no setter
amount → int
no setter
channel → int?
no setter
city → String?
no setter
client → String?
no setter
country → String
no setter
crc → String
no setter
currency → String
no setter
description → String
no setter
email → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
language → String?
no setter
merchantId → int
no setter
method → int?
no setter
methodRefId → String?
no setter
passageCart ↔ PassageCart?
getter/setter pair
phone → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → String
no setter
shipping → int?
no setter
timeLimit → int?
no setter
transferLabel → String?
no setter
urlStatus → String?
no setter
zip → String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putIfValueNotNull(String key, dynamic value, Map<String, dynamic> map) → void
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited